aboutsummaryrefslogtreecommitdiff
path: root/src/lib.ts
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib.ts')
-rw-r--r--src/lib.ts25
1 files changed, 12 insertions, 13 deletions
diff --git a/src/lib.ts b/src/lib.ts
index 4fd999b..56b6c8d 100644
--- a/src/lib.ts
+++ b/src/lib.ts
@@ -48,38 +48,37 @@ export type UiOptions = {
// Shared styling
borderRadius: number, // CSS border-radius value, in px
shadowNormal: string, // CSS box-shadow value
- shadowHighlight: string,
+ shadowHovered: string,
shadowFocused: string,
// Styling for App
appBgColor: string, // CSS color
- tileAreaOffset: number, // Space between root tile and display boundary, in px
+ titleBarBgColor: string, // CSS color
+ mainTileMargin: number, // px
// Styling for tiles
- headerColor: string, // CSS color
- childThresholds: [number, string][],
- // Specifies, for an increasing sequence of minimum-child-quantity values, CSS color to use
+ textColor: string, // CSS color
+ childQtyColors: [number, string][],
+ // Specifies, for an increasing sequence of minimum-child-quantity values, CSS colors to use
//eg: [[1, 'green'], [10, 'orange'], [100, 'red']]
infoIconSz: number, // px
infoIconMargin: number, // px
- leafTilePadding: number, // px
+ leafPadding: number, // px
leafHeaderFontSz: number, // px
nonleafBgColors: string[],
// Specifies CSS colors to use at various tree depths
// With N strings, tiles at depth M use the color at index M % N
nonleafHeaderFontSz: number, // px
- nonleafHeaderColor: string, // CSS color
nonleafHeaderBgColor: string, // CSS color
// Styling for other components
infoModalImgSz: number, // px
ancestryBarBgColor: string, // CSS color
ancestryBarImgSz: number, // px
- ancestryTileMargin: number, // px (gap between detached-ancestor tiles)
- tutorialPaneSz: number, // px
- tutorialPaneBgColor: string, // CSS color
- tutorialPaneTextColor: string, // CSS color
+ ancestryTileGap: number, // Gap between ancestor tiles, in px
+ tutPaneSz: number, // px
+ tutPaneBgColor: string, // CSS color
// Timing related
clickHoldDuration: number, // Time after mousedown when a click-and-hold is recognised, in ms
- tileChgDuration: number, // Transition time for tile_move/etc, in ms
- autoWaitTime: number, // Time between actions, in ms
+ transitionDuration: number, // ms
+ autoActionDelay: number, // Time between auto-mode actions, in ms
// Other
useReducedTree: boolean,
searchSuggLimit: number, // Max number of search suggestions